# morphapi

## Overview
Morphapi is a lightweight python package for downloading neurons
morphological reconstructions from publicly available datasets. 

Check out the [official documentation](https://docs.brainglobe.info/morphapi/morphapi)
